/*
 * TimeLabelCanvas.java
 * ------------------
 * Separated and modified by David Wong
 */
import java.awt.*;
import java.awt.Image;
import java.awt.image.ImageObserver;

class TimeLabelCanvas extends Canvas {
    private Dimension offDimension;
    private Image offImage;
    private Graphics offGraphics;
    private Font font;
    private FontMetrics fm;

    private IsingLattice lattice;        // actual grid, here is where all the physics happens
    
    public TimeLabelCanvas (IsingLattice lattice, Font f) {
	this.lattice = lattice;
	font = f;
    }
    
    /**
     * Paint the time on the canvas
     */
    public void paint  (Graphics g) {
	update (g);
    }
    /**
     * Set the preferred size of this canvas
     */
    public Dimension getPreferredSize  () {
	return new Dimension (180, 20);
    }
    /**
     * 
     */
    public Dimension getMinimumSize  () {
	return getPreferredSize ();
    }
    /**
     * Print out the graph
     */
    public void update  (Graphics g) {
	String s = "t="+lattice.getTotalTime ();
	Dimension d = getSize ();
	if ((offGraphics == null)
	   || (d.width != offDimension.width)
           || (d.height != offDimension.height)) {
	  offDimension = d;
	  offImage = createImage (d.width, d.height);
	  offGraphics = offImage.getGraphics ();
	  offGraphics.setFont (font);
	  fm = offGraphics.getFontMetrics ();
	}
	offGraphics.setColor (getBackground ());
	offGraphics.fillRect (0, 0, d.width, d.height);
	offGraphics.setColor (Color.black);
	int x = (d.width - fm.stringWidth (s))/2;
	offGraphics.drawString (s, x, d.height);
	g.drawImage (offImage, 0, 0, this);
    }
}
